@@ -196,7 +196,9 @@ if ( isset($_POST["user"]) && isset($_POST["password"]) ) {
     $nonce_check = $SecMan->check_nonce($_SESSION['nonce'],$NetInfo->get_client_ip());
     if ( $nonce_check == FALSE ) {
         unset($_SESSION['nonce']);
-        if ( $_SERVER['SCRIPT_FILENAME'] != '/docker/whp/web/login.php' && !is_api_endpoint()) {
+        if ( $_SERVER['SCRIPT_FILENAME'] != '/docker/whp/web/login.php' && 
+             $_SERVER['SCRIPT_FILENAME'] != '/docker/whp/web/blocked.php' && 
+             !is_api_endpoint()) {
             if ( empty($_SERVER['HTTPS'] ) ) {
                 $protocol = "http://";
                 $port = "8080";
@@ -276,7 +278,10 @@ if ( isset($_POST["user"]) && isset($_POST["password"]) ) {
         exit();
     }
 }else {
-    if ( $_SERVER['SCRIPT_FILENAME'] != '/docker/whp/web/login.php' && !is_api_endpoint()) {
+    // Don't require authentication for login.php, blocked.php, or API endpoints
+    if ( $_SERVER['SCRIPT_FILENAME'] != '/docker/whp/web/login.php' && 
+         $_SERVER['SCRIPT_FILENAME'] != '/docker/whp/web/blocked.php' && 
+         !is_api_endpoint()) {
         if ( empty($_SERVER['HTTPS'] ) ) {
             $protocol = "http://";
             $port = "8080";
