@@ -473,9 +473,16 @@ class BackupEngine {
         try {
             // Create site backup (files)
             $siteBackupResult = $this->createSiteBackup($site['user'], $site['domain'], $targetId);
-            
-            // Create database backup
-            $dbBackupResult = $this->createDatabaseBackup($site['user'], $site['database_name'], $targetId);
+
+            // Create database backup only if database name is available
+            $dbBackupResult = null;
+            if (!empty($site['database_name'])) {
+                $dbBackupResult = $this->createDatabaseBackup($site['user'], $site['database_name'], $targetId);
+            } else {
+                // Log warning but continue with file backup only
+                error_log("Warning: WordPress site {$site['domain']} has no database configured, creating file backup only");
+                $dbBackupResult = ['success' => true, 'backup_id' => null, 'size' => 0];
+            }
             
             // Create combined backup record
             $history = new BackupHistory($this->db);
@@ -485,16 +492,17 @@ class BackupEngine {
                 'backup_type' => 'wordpress',
                 'backup_name' => $backupName,
                 'backup_path' => "wordpress/{$site['domain']}/",
-                'source_path' => "/docker/users/{$site['user']}/{$site['domain']}",
-                'size' => ($siteBackupResult['size'] ?? 0) + ($dbBackupResult['size'] ?? 0),
-                'metadata' => json_encode([
+                'backup_size' => ($siteBackupResult['size'] ?? 0) + ($dbBackupResult['size'] ?? 0),
+                'status' => 'completed',
+                'metadata' => [
                     'wordpress_site_id' => $siteId,
                     'domain' => $site['domain'],
-                    'database' => $site['database_name'],
+                    'database' => $site['database_name'] ?? null,
                     'site_backup_id' => $siteBackupResult['backup_id'] ?? null,
                     'db_backup_id' => $dbBackupResult['backup_id'] ?? null,
-                    'wp_version' => $site['wp_version'] ?? null
-                ])
+                    'wp_version' => $site['wp_version'] ?? null,
+                    'source_path' => "/docker/users/{$site['user']}/{$site['domain']}"
+                ]
             ]);
             
             return [
